BufferPool

Struct BufferPool 

pub struct BufferPool { /* private fields */ }
LRU buffer pool for page caching.

Implementations

Source

impl BufferPool

pub fn new(config: BufferPoolConfig) -> Self

Create a new buffer pool with the given configuration.

pub fn with_capacity(num_pages: usize) -> Self

Create a buffer pool with default configuration.

pub fn fetch_page(&self, page_id: PageId) -> Result<PageHandle>

Fetch a page from the pool, loading it if necessary.

pub fn new_page( &self, page_id: PageId, page_type: PageType, ) -> Result<PageHandle>

Create a new page in the pool.

pub fn flush_page(&self, page_id: PageId) -> Result<Option<Page>>

Flush a specific page to storage.

pub fn unpin_page(&self, page_id: PageId)

Unpin a page, allowing it to be evicted.

pub fn stats(&self) -> BufferPoolStats

Get buffer pool statistics.